==> xcsoar-6.8.4.tar.xz: xcsoar-6.8.4/src/Widget/LargeTextWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LARGE_TEXT_WIDGET_HPP
#define XCSOAR_LARGE_TEXT_WIDGET_HPP

#include "WindowWidget.hpp"

#include <tchar.h>

struct DialogLook;

/**
 * A #Widget implementation that displays multi-line text.
 */
class LargeTextWidget : public WindowWidget {
  const DialogLook &look;
  const TCHAR *text;

public:
  LargeTextWidget(const DialogLook &_look, const TCHAR *_text=nullptr)
    :look(_look), text(_text) {}

  void SetText(const TCHAR *text);

  /* virtual methods from class Widget */
  void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
  void Unprepare() override;
  bool KeyPress(unsigned key_code) override;
};

#endif

==> xcsoar-7.11.tar.xz: xcsoar-7.11/src/Widget/LargeTextWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LARGE_TEXT_WIDGET_HPP
#define XCSOAR_LARGE_TEXT_WIDGET_HPP

#include "WindowWidget.hpp"

#include <tchar.h>

struct DialogLook;

/**
 * A #Widget implementation that displays multi-line text.
 */
class LargeTextWidget : public WindowWidget {
  const DialogLook &look;
  const TCHAR *text;

public:
  explicit LargeTextWidget(const DialogLook &_look,
                           const TCHAR *_text=nullptr) noexcept
    :look(_look), text(_text) {}

  void SetText(const TCHAR *text) noexcept;

  /* virtual methods from class Widget */
  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
  bool KeyPress(unsigned key_code) noexcept override;
};

#endif
